@@ -652,14 +652,16 @@ def test_init_project_from_template_source_path_local_copier(
     project_dir = GENERATED_FILES_DIR / "project"
     # Ensure project is a git repo
     repo = Repo(project_dir)
-    assert repo.commit().message == "Remove temporary file\n"
+    assert_main_commit_message_matches(
+        repo.commit().message, "Update flexlate templates"
+    )
 
     content_path = project_dir / "a1.txt"
     content = content_path.read_text()
     assert content == "1"
 
-    non_content_path = project_dir / "README.md"
-    assert not non_content_path.exists()
+    readme_path = project_dir / "README.md"
+    assert readme_path.read_text() == "some existing content"
 
     config_path = project_dir / "flexlate.json"
     config = FlexlateConfig.load(config_path)
